@@ -121,13 +121,13 @@ fit_mrs <- function(metab, basis = NULL, method = 'VARPRO_3P', w_ref = NULL, opt
     
   } else if (METHOD == "TARQUIN") {
     if (!is.null(w_ref)) { 
-      if (dyns(w_ref) > 1) {
+      if (Ndyns(w_ref) > 1) {
         w_ref <- mean_dyns(w_ref)
         warning("Using the mean reference signal for water scaling.")
       }
       # repeat the refernce signal to match the number of dynamics
-      if (dyns(metab) > 1) {
-        w_ref <- rep_dyn(w_ref, dyns(metab))
+      if (Ndyns(metab) > 1) {
+        w_ref <- rep_dyn(w_ref, Ndyns(metab))
       }
     }
     
@@ -157,14 +157,14 @@ fit_mrs <- function(metab, basis = NULL, method = 'VARPRO_3P', w_ref = NULL, opt
                          #.paropts = list(.export="N",.packages="spant"),
   } else if (METHOD == "LCMODEL") {
     if (!is.null(w_ref)) { 
-      if (dyns(w_ref) > 1) {
+      if (Ndyns(w_ref) > 1) {
         w_ref <- mean_dyns(w_ref)
         warning("Using the mean reference signal for water scaling.")
       }
       
       # repeat the reference signal to match the number of dynamics
-      if (dyns(metab) > 1) {
-        w_ref <- rep_dyn(w_ref, dyns(metab))
+      if (Ndyns(metab) > 1) {
+        w_ref <- rep_dyn(w_ref, Ndyns(metab))
       }
     }
     
@@ -394,7 +394,7 @@ lcmodel_fit <- function(element, temp_mrs, basis_file, opts) {
 }
 
 #' Reader for csv results generated by TARQUIN.
-#' @param result_f TARQIUN result file.
+#' @param result_f TARQUIN result file.
 #' @param remove_rcs omit row, column and slice ids from output.
 #' @return list of amplitudes, crlbs and diagnostics.
 #' @examples
@@ -545,13 +545,13 @@ fit_diags <- function(x, amps = NULL) {
   }
 }
 
-#' Extract the fit amplitues from an object of class \code{fit_result}.
+#' Extract the fit amplitudes from an object of class \code{fit_result}.
 #' @param x \code{fit_result} object.
 #' @param inc_index include columns for the voxel index.
 #' @param sort_names sort the basis set names alphabetically.
 #' @param append_common_1h_comb append commonly used 1H metabolite combinations
 #' eg TNAA = NAA + NAAG.
-#' @return a dataframe of amplidudes.
+#' @return a dataframe of amplitudes.
 #' @export
 fit_amps <- function(x, inc_index = FALSE, sort_names = TRUE,
                      append_common_1h_comb = TRUE) {
@@ -594,4 +594,27 @@ fit_amps <- function(x, inc_index = FALSE, sort_names = TRUE,
   }
   
   out
+}
+
+#' Combine a list of fit_result objects into a single fit object containing a 
+#' dynamic series.
+#' @param fit_list list of fit_result objects.
+#' @return fit_result object.
+#' @export
+comb_fits <- function(fit_list) {
+  res_tab <- do.call(rbind, lapply(fit_list, `[[`, "res_tab"))
+  res_tab$Dynamic <- 1:length(fit_list)
+  fits <- unlist(lapply(fit_list, `[[`, "fits"), FALSE)
+  data <- append_dyns(lapply(fit_list, `[[`, "data"))
+  proc_time <- fit_list[[1]]$proc_time
+  for (n in 2:length(fit_list)) {
+    proc_time <- proc_time + fit_list[[n]]$proc_time
+  }
+  
+  fit_out <- list(res_tab = res_tab, fits = fits, data = data,
+                  basis = fit_list[[1]]$basis,
+                  amp_cols = fit_list[[1]]$amp_cols, proc_time = proc_time)
+  
+  class(fit_out) <- "fit_result"
+  fit_out
 }
\ No newline at end of file
